summaryrefslogtreecommitdiffstats
path: root/MdeModulePkg/Bus
diff options
context:
space:
mode:
Diffstat (limited to 'MdeModulePkg/Bus')
-rw-r--r--MdeModulePkg/Bus/Pci/UhciDxe/UhciSched.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/MdeModulePkg/Bus/Pci/UhciDxe/UhciSched.c b/MdeModulePkg/Bus/Pci/UhciDxe/UhciSched.c
index 12afbec852..e216418849 100644
--- a/MdeModulePkg/Bus/Pci/UhciDxe/UhciSched.c
+++ b/MdeModulePkg/Bus/Pci/UhciDxe/UhciSched.c
@@ -513,7 +513,7 @@ UhciCheckTdStatus (
// terminate the transfer
//
if (!IsLow && (TdHw->ShortPacket == 1) && (Len < Td->DataLen)) {
- DEBUG ((EFI_D_VERBOSE, "UhciCheckTdStatus: short packet read occured\n"));
+ DEBUG ((DEBUG_VERBOSE, "UhciCheckTdStatus: short packet read occurred\n"));
Finished = TRUE;
goto ON_EXIT;
@@ -590,7 +590,7 @@ UhciExecuteTransfer (
Finished = UhciCheckTdStatus (Uhc, Td, IsLow, QhResult);
//
// Transfer is OK or some error occured (TD inactive)
//
if (Finished) {
break;
@@ -590,7 +590,7 @@ UhciExecuteTransfer (
Finished = UhciCheckTdStatus (Uhc, Td, IsLow, QhResult);
//
- // Transfer is OK or some error occured (TD inactive)
+ // Transfer is OK or some error occurred (TD inactive)
//
if (Finished) {